#
# spec file for package audacious
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define aud_plugin_ver_min 3.9
%define aud_plugin_ver_max 3.9.99
%define core_soname 5
%define qt_soname 2
%define gui_soname 5
%define tag_soname 3
Name:           audacious
Version:        3.9
Release:        lp150.1.8
Summary:        Audio player with graphical UI and library functionality
License:        BSD-2-Clause
Group:          Productivity/Multimedia/Sound/Players
Url:            http://audacious-media-player.org/
Source:         https://github.com/audacious-media-player/audacious/archive/%{name}-%{version}-gtk3.tar.gz
# PATCH-FIX-UPSTREAM audacious-no-inode-directory-mimetype.patch i@marguerite.su -- Don't open directories with Audacious.
Patch:          audacious-no-inode-directory-mimetype.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++ >= 4.5
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1) >= 1.0.2
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.88
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.32
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.32
BuildRequires:  pkgconfig(libguess) >= 1.2
Requires:       %{name}-plugins%{?_isa} <= %{aud_plugin_ver_max}
Requires:       %{name}-plugins%{?_isa} >= %{aud_plugin_ver_min}
Recommends:     %{name}-lang
Recommends:     %{name}-plugins-extra >= %{aud_plugin_ver_min}
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4
BuildRequires:  pkgconfig(Qt5Core) >= 5.2
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2

%description
Audacious is an audio player. It is based on GTK+ and supports a wide
range of audio codecs. It still features an alternative skinned user
interface (based on Winamp 2.x skins). Historically, it started as a
fork of a fork of XMMS.

%lang_package

%package -n libaudcore%{core_soname}
Summary:        Main functionality library of Audacious
Group:          System/Libraries
Provides:       libaudcore%{?_isa} = %{version}

%description -n libaudcore%{core_soname}
Library from the Audacious audio player.

%package -n libaudqt%{qt_soname}
Summary:        QT GUI implementation of Audacious
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudqt%{qt_soname}
Library from the Audacious audio player.

%package -n libaudgui%{gui_soname}
Summary:        GTK GUI implementation of Audacious
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudgui%{gui_soname}
Library from the Audacious audio player.

%package -n libaudtag%{tag_soname}
Summary:        ID3 and APE metadata support for Audacious
Group:          System/Libraries
Requires:       libaudcore%{core_soname} >= %{version}

%description -n libaudtag%{tag_soname}
Library from the Audacious audio player.

%package devel
Summary:        Development files for Audacious
Group:          Development/Libraries/C and C++
Requires:       libaudcore%{core_soname} = %{version}
Requires:       libaudtag%{tag_soname} = %{version}
Requires:       libaudqt%{qt_soname} = %{version}
Requires:       libaudgui%{gui_soname} = %{version}

%description devel
Development files for Audacious audio player.

%prep
%setup -q -n %{name}-%{name}-%{version}-gtk3
%patch -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-qt     \
  --enable-gtk    \
  --disable-rpath
make %{?_smp_mflags} V=1

%install
%make_install
install -Dpm 0644 contrib/%{name}.appdata.xml %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n libaudcore%{core_soname} -p /sbin/ldconfig

%postun -n libaudcore%{core_soname} -p /sbin/ldconfig

%post -n libaudqt%{qt_soname} -p /sbin/ldconfig

%postun -n libaudqt%{qt_soname} -p /sbin/ldconfig

%post -n libaudgui%{gui_soname} -p /sbin/ldconfig

%postun -n libaudgui%{gui_soname} -p /sbin/ldconfig

%post -n libaudtag%{tag_soname} -p /sbin/ldconfig

%postun -n libaudtag%{tag_soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_bindir}/%{name}
%{_bindir}/audtool
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_mandir}/man?/audtool.?%{?ext_man}

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n libaudcore%{core_soname}
%defattr(-,root,root)
%{_libdir}/libaudcore.so.%{core_soname}*

%files -n libaudqt%{qt_soname}
%defattr(-,root,root)
%{_libdir}/libaudqt.so.%{qt_soname}*

%files -n libaudgui%{gui_soname}
%defattr(-,root,root)
%{_libdir}/libaudgui.so.%{gui_soname}*

%files -n libaudtag%{tag_soname}
%defattr(-,root,root)
%{_libdir}/libaudtag.so.%{tag_soname}*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_includedir}/libaudcore/
%{_libdir}/libaudcore.so
%{_includedir}/libaudqt/
%{_libdir}/libaudqt.so
%{_includedir}/libaudgui/
%{_libdir}/libaudgui.so
%{_libdir}/libaudtag.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Oct 29 2017 olaf@aepfle.de
- Remove the versioned conditional for Qt build.
  It builds fine in PackageHub, and audacious-plugins expects the
  Qt variant.
- Remove Qt and GTK conditionals, they are always enabled and the
  name is too generic
- Remove conditional for appdata for obsolete Leap 42.1
* Wed Aug 23 2017 aloisio@gmx.com
- Update to version 3.9
  Qt UI enhancements:
  * More configurable main window, with new View menu and
    additional options in Settings (#657)
  * Full drag-and-drop capability for playlist entries
  * Configurable playlist columns (add, remove, resize, and
    rearrange)
  * New controls for stream recording
  * Improved playlist search bar, which hides until Control+F is
    pressed, matches results more intelligently, and even mimics
    the keyboard controls of the old 'Jump to Song' dialog
  * Integrated menu items and keyboard shortcuts for the
    Playlist Manager and Search Tool
  * More detailed yet unobtrusive reporting of errors via the
    status bar
  * Visual indication when 'Stop After This Song' is active, by
    making the stop button a toggle
  * Better high-DPI support and many other cosmetic fixes
  Usability improvements:
  * A Comments column can be displayed in the playlist, and used
    to sort it (#560)
  * Bold, italics, and capitals highlight different types of
    results in the GTK+ version of the Search Tool (#701)
  * The Record button is hidden to prevent accidental usage
    until recording is enabled in Settings (#703)
  * Recording settings can be changed without immediately
    starting to record the currently playing stream
  * The unhelpful "Unknown playback error" message has been
    removed
  Advanced features:
  * audtool gains better support for multiple playlists with the
  - -select-displayed and --select-playing commands (#609)
  * Recursive adding of folders specified in M3U playlists (#731)
  * Direct output to ALSA devices that require packed 24-bit
    audio
  * Automatic switching between track and album ReplayGain modes
    when shuffle is enabled/disabled
  * Option in Speed and Pitch effect to adjust both parameters
    in lockstep, thereby preventing distortion
  Under the hood:
  * Conversion of a substantial amount of C-like code to safer
    C++ practices
  * For the Windows build, an update to the newer MinGW-w64
    toolchain (still 32-bit)
- Changed source URL
* Tue May 16 2017 jengelh@inai.de
- Ensure neutrality of description.
  Update package summaries so they are not all the same.
* Thu Jan 26 2017 sor.alexei@meowr.ru
- Update to version 3.8.2:
  * No changelog available.
* Wed Dec  7 2016 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * No changelog available.
- Rebase audacious-no-inode-directory-mimetype.patch
* Fri Sep 23 2016 sor.alexei@meowr.ru
- Update to version 3.8:
  * No changelog available.
- Rebase audacious-no-inode-directory-mimetype.patch
- Install the appstream file to /usr/share/metainfo/ instead of
  /usr/share/appdata/ on openSUSE Leap 42.2 and newer.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to 3.7.2.
* Fri Mar 25 2016 i@marguerite.su
- fix boo#972690: audacious is used to open directory
- add patch: audacious-no-inode-directory-mimetype.patch
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 3.7.1.
* Fri Nov 13 2015 aloisio@gmx.com
- Fixes audacious-plugins build on 13.1
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 3.7.
- Enable Qt UI.
* Fri Aug 21 2015 sor.alexei@meowr.ru
- Work with Audacious plugin versions instead of ABI versions to
  simplify things a lot.
* Mon Jun  1 2015 sor.alexei@meowr.ru
- Update to 3.6.2.
* Sat Apr  4 2015 sor.alexei@meowr.ru
- Update to 3.6.1.
* Sun Mar  1 2015 sor.alexei@meowr.ru
- Update to 3.6.
* Sun Dec 28 2014 sor.alexei@meowr.ru
- Update to 3.5.2.
- Spec cleanup.
* Tue Dec 17 2013 reddwarf@opensuse.org
- Update to 3.4.2
* Fri Mar 29 2013 fisiu@opensuse.org
- Update to 3.3.4:
  * Ported from gtk2 to gtk3
  * Save current track position
  * Improved search feature
  * Many bug fixes
* Sun Aug 19 2012 seife+obs@b1-systems.com
- update to current version 3.2.4
- removed no longer necessary -lgmodule-2.0 hack
* Tue May 22 2012 seife+obs@b1-systems.com
- fix build on > 12.1 by adding -lgmodule-2.0 to LIBS
* Fri Dec  9 2011 detlef@links2linux.de
- new upstream version <3.1.1>
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- update to 3.1
* Sun Nov  6 2011 detlef@links2linux.de
- new upstream version <3.0.3>
* Sun Aug 28 2011 detlef@links2linux.de
- new upstream version <3.0.2>
* Sat Aug 13 2011 detlef@links2linux.de
- new upstream version <3.0.1>
* Sat Jul  2 2011 detlef@links2linux.de
- new upstream version <2.5.3>
* Thu Jun 23 2011 detlef@links2linux.de
- new upstream version <2.5.2>
* Sat May 21 2011 detlef@links2linux.de
- new upstream version <2.5.1>
* Sun Apr 17 2011 detlef@links2linux.de
- new upstream version <2.5.0>
* Wed Feb 23 2011 detlef@links2linux.de
- new upstream version <2.4.4>
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <2.4.3>
* Wed Dec  8 2010 detlef@links2linux.de
- new upstream version <2.4.2>
* Fri Aug 27 2010 detlef@links2linux.de
- enable libguess support
* Wed Aug 25 2010 detlef@links2linux.de
- new upstream version <2.4-rc3>
* Fri Apr  9 2010 detlef@links2linux.de
- new upstream version <2.3>
* Wed Nov 25 2009 detlef@links2linux.de
- new upstream version <2.2>
* Wed Jul  8 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.1>
* Fri Jun  5 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.0.1>
* Tue Jul 22 2008 guru@unixtech.be
- added InitialPreference to action_audacious.desktop as it is
  associated with directories, in order to avoid it being the
  default action on directories
- added patch to fix specifying files on the command-line when
  audacious isn't already running:
  http://bugzilla.atheme.org/show_bug.cgi?id=48
* Sun Jul 20 2008 detlef@links2linux.de
- require audacious-plugins instead of audacious-plugins-option
  package managers are stupid ;)
* Thu Jul 10 2008 guru@unixtech.be
- require audacious-plugins-option instead of audacious-plugins
* Sun Jul  6 2008 guru@unixtech.be
- split shared libraries into its own -libs subpackage to avoid the
  chicken/egg problem when building audacious and audacious-plugins
  (as they both require each other), with audacious now requiring
  audacious-libs
- minor spec file cleanups
- added Provides for shlibs, openSUSE Shared Library Policy compliant
- more explicit filenames in files sections
- better Summary
- added glib backport patch to build on openSUSE 10.2
* Mon May 26 2008 detlef@links2linux.de
- new upstream version <1.5.1>
* Tue Apr 22 2008 detlef@links2linux.de
- fix Requires for devel
* Sun Mar 30 2008 detlef@links2linux.de
- disable ss2 for ix86, some old cpus doesn't support sse2
* Sat Mar 15 2008 detlef@links2linux.de
- new upstream version <1.5.0>
* Mon Feb 18 2008 detlef@links2linux.de
- rebuild with new libmcs-0.7
* Fri Feb  1 2008 detlef@links2linux.de
- new upstream version <1.4.6>
* Sat Dec 29 2007 detlef@links2linux.de
- new upstream version <1.4.5>
* Sat Dec 22 2007 detlef@links2linux.de
- rebuild for new libmcs and libmowgli
* Sat Dec  8 2007 detlef@links2linux.de
- add servicemenu for konqueror and dolphin
* Mon Dec  3 2007 detlef@links2linux.de
- new upstream version <1.4.4>
* Sat Dec  1 2007 detlef@links2linux.de
- new upstream version <1.4.3>
* Mon Nov 19 2007 detlef@links2linux.de
- new upstream release <1.4.1>
* Tue Nov  6 2007 detlef@links2linux.de
- new upstream release <1.4.0>
* Mon Nov  5 2007 detlef@links2linux.de
- switch to 1.4 on PackMan
- Audacious 1.4 is now complete, and is now recommended over 1.3
* Fri Nov  2 2007 detlef@links2linux.de
- new upstream release <1.4.0-rc1>
* Mon Oct 29 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta4>
* Fri Oct 19 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta2>
* Mon Oct 15 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta1>
* Thu Sep 20 2007 detlef@links2linux.de
- add xchat-plugin
* Thu Sep 13 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr4>
* Sun Sep  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr3>
* Thu Aug  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr2>
- fix BuildRequires -> add dbus-support
* Mon Jul 23 2007 detlef@links2linux.de
- initial build <1.4.0-dr1>
